Stan Math Library: stan/math/fwd/mat/fun/mdivide_left_ldlt.hpp File Reference

| Stan Math Library 2.10.0 reverse mode automatic differentiation

- Main Page
- Modules
- Namespaces
- Classes
- Files

- File List
- File Members

Namespaces | Functions
mdivide_left_ldlt.hpp File Reference
`#include <stan/math/prim/mat/fun/Eigen.hpp>`
`#include <stan/math/prim/mat/fun/LDLT_factor.hpp>`
`#include <stan/math/prim/mat/err/check_multiplicable.hpp>`
`#include <stan/math/prim/mat/fun/promote_common.hpp>`
`#include <stan/math/prim/mat/fun/mdivide_left_ldlt.hpp>`
`#include <stan/math/fwd/mat/fun/to_fvar.hpp>`
`#include <boost/math/tools/promotion.hpp>`

Go to the source code of this file.

## Namespaces
| stan
| stan::math
| Matrices and templated mathematical functions.

## Functions
template<int R1, int C1, int R2, int C2, typename T2 >
Eigen::Matrix< fvar< T2 >, R1, C2 > | stan::math::mdivide_left_ldlt (const stan::math::LDLT_factor< double, R1, C1 > &A, const Eigen::Matrix< fvar< T2 >, R2, C2 > &b)
| Returns the solution of the system Ax=b given an LDLT_factor of A. More...

[ Stan Home Page ] © 2011–2016, Stan Development Team.